@@ -43,46 +43,27 @@ impl<const N: IntLayout> Aligner for AlignWrap<N> {
     default type A = i128;
 }
 
+macro_rules! alignwrap {
+    (  $($tt:ident)* ) => {
+        $(
+            impl const Aligner for AlignWrap<{ IntLayout::$tt }> {
+                type A = $tt;
+            }
+        )+
+    };
+}
+
 // Convert the IntLayout into the corresponding type
 #[doc(hidden)]
 #[derive(Copy, Clone)]
 pub struct AlignWrap<const N: IntLayout>;
-impl Aligner for AlignWrap<{ IntLayout::Trivial }> {
-    type A = Trivial;
-}
-impl Aligner for AlignWrap<{ IntLayout::i8 }> {
-    type A = i8;
-}
-impl Aligner for AlignWrap<{ IntLayout::u8 }> {
-    type A = u8;
-}
-impl Aligner for AlignWrap<{ IntLayout::i16 }> {
-    type A = i16;
-}
-impl Aligner for AlignWrap<{ IntLayout::u16 }> {
-    type A = u16;
-}
-impl Aligner for AlignWrap<{ IntLayout::i32 }> {
-    type A = i32;
-}
-impl Aligner for AlignWrap<{ IntLayout::u32 }> {
-    type A = u32;
-}
-impl Aligner for AlignWrap<{ IntLayout::i64 }> {
-    type A = i64;
-}
-impl Aligner for AlignWrap<{ IntLayout::u64 }> {
-    type A = u64;
-}
-impl Aligner for AlignWrap<{ IntLayout::i128 }> {
-    type A = i128;
-}
+alignwrap!{Trivial i8 u8 i16 u16 i32 u32 i64 u64 i128 }
 
 // The internal representation of Ranged: an array of bytes with the length and alignmemt ensured
 #[derive(Clone, Copy)]
-pub(crate) struct NumberBytes<const LAYOUT: IntLayout>
+pub struct NumberBytes<const LAYOUT: IntLayout>
 where
-    [(); LAYOUT.bytes()]: ,
+    [(); LAYOUT.bytes()]:,
 {
     // Ensure the alignment
     _align: [<AlignWrap<LAYOUT> as Aligner>::A; 0],
@@ -96,11 +77,11 @@ impl<const LAYOUT: IntLayout> NumberBytes<LAYOUT>
 where
     [(); LAYOUT.bytes()]: ,
 {
-    #[inline]
+    #[inline(always)]
     pub(crate) const fn from_irang(v: irang) -> Self {
         macro_rules! conv_from_irang {
             (  $($tt:ident)* ) => {
-                match LAYOUT {
+                match const{LAYOUT} {
                     IntLayout::Trivial => {Self {_align:[], bytes: [0; LAYOUT.bytes()]}}
                     $(
                         IntLayout::$tt => {
@@ -114,11 +95,11 @@ where
         conv_from_irang! {i8 u8 i16 u16 i32 u32 i64 u64 i128}
     }
 
-    #[inline]
+    #[inline(always)]
     pub(crate) const fn to_irang(self) -> irang {
         macro_rules! conv_to_irang {
             (  $($tt:ident)* ) => {
-                match LAYOUT {
+                match const{LAYOUT} {
                     IntLayout::Trivial => {unreachable!()}
                     $(
                         IntLayout::$tt => {
