@@ -1,24 +1,46 @@
 //! # Ranged integers [nightly only]
 //!
-//! The crate provides an integer type restricted to a compile time defined range with
-//! automatic size selection and automatic bounds calulation for arithmetics.
+//! The crate provides [an integer type](struct.Ranged.html) restricted to a compile time defined range with
+//! automatic data size selection, automatic bounds calulation for arithmetics and the possibility
+//! of fixed-size array indexing and range iteration.
 //!
-//! [`Ranged<const MIN: i128, const MAX: i128>`](struct.Ranged.html) is bounded to [MIN, MAX] interval **inclusively**.
+//! # Prerequisites
 //!
+//! The library usage requires the following Rust features enabled in the user crate or application:
+//!
+//! ```
+//! // Without this rustc generates errors and sometimes panics.
+//! #![feature(adt_const_params, generic_const_exprs)]
+//! ```
+//! 
 //! # Usage and examples
-//!
-//! ## Prerequisites
-//!
-//! The library usage requires the following Rust feature enabled in the user crate or application:
+//! 
+//! ## Ranged semantics
+//! 
+//! Use `Ranged<MIN, MAX>` type to be sure of the value range:
 //!
 //! ```
-//! // Without this the Ranged arithmetics and conversion functions fail.
-//! #![feature(const_generics)]
+//! # use ranged_integers::*;
+//! fn move_player(dice_roll: Ranged<1, 6>) {
+//!     let x : i32 = dice_roll.into(); // Conversion is allowed, i32 can store 1..=6
+//! }
 //! ```
 //!
-//! ## Integer size
+//! ## Contents
+//! 
+//! * [Data layout paradigm](#data-layout-paradigm)
+//! * [Ranged and integer primitives](#ranged-and-integer-primitives)
+//!    - [Creation of Ranged at compile time](#creation-of-ranged-at-compile-time)
+//!    - [Ranged -> Ranged conversion](#ranged---ranged-conversion)
+//!    - [int -> Ranged conversion](#int---ranged-conversion)
+//!    - [Ranged -> int conversion](#ranged---int-conversion)
+//! * [Array indexing and iteration](#array-indexing-and-iteration)
+//! * [Comparison](#comparison)
+//! * [Arithmetics](#arithmetics)
+//! 
+//! ## Data layout paradigm
 //!
-//! The [`Ranged`](struct.Ranged.html) automatically chooses the smallest size possible according
+//! The [Ranged] automatically chooses the smallest size possible according
 //! to `MIN..=MAX` range.
 //! It supports i8, u8, i16, u16, i32, u32, i64, u64 and i128 layouts (u128 is not supported),
 //! and a special zero-size layout for "constant" values with `MIN==MAX`.
@@ -38,25 +60,16 @@
 //!
 //! The implementation heavily relies on the optimizer.
 //!
-//! ## Ranged and primitive interaction
+//! ## Ranged and integer primitives
 //!
-//! Use `Ranged<MIN, MAX>` type to be sure of the value range:
+//! ### Creation of `Ranged` at compile time
+//!
+//! The [`Ranged::create_const`] can be used to create a 
+//! [`Ranged`] value checking it at compile time.
+//! The macro [`r!`] does the same but a bit shorter.
 //!
 //! ```
-//! # use ranged_integers::*;
-//! fn move_player(dice_roll: Ranged<1, 6>) {
-//!     let x : i32 = dice_roll.into(); // Conversion is allowed, i32 can store 1..=6
-//! }
-//! ```
-//!
-//! ### Create Ranged at compile time
-//!
-//! The [`Ranged::create_const`](struct.Ranged.html#method.create_const) can be used to create a 
-//! [`Ranged`](struct.Ranged.html) value checking it at compile time.
-//! The macro [`r!`](macro.r.html) does the same but a bit shorter.
-//!
-//! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! // Way 1: specify the bounds explicitly
 //! move_player(Ranged::<1,6>::create_const::<4>());
 //! move_player(r!([1 6] 4));  // Same thing
@@ -75,7 +88,7 @@
 //! It fails if the bounds are corrupted:
 //!
 //! ```compile_fail
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! move_player(r!([] 7)); // Error: Can't store 7 in [1 6] inverval
 //! ```
 //! ```compile_fail
@@ -89,7 +102,7 @@
 //! and [`try_expand()->Option`](struct.Ranged.html#method.try_expand) (runtime check).
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! let expandable: Ranged<4, 5> = r!([] 5);  // Fits Ranged<1,6> accepted by move_player
 //! let overlapping: Ranged<4, 9> = r!([] 5);  // Doesn't fit, but the value 5 is acceptable
 //! move_player(expandable.expand());
@@ -99,7 +112,7 @@
 //! Shrinking with `expand()` is forbidden:
 //!
 //! ```compile_fail
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! # let overlapping: Ranged<4, 9> = r!([] 5);
 //! move_player(overlapping.expand());  // Error: the bounds 4..=9 can't fit in 1..=6
 //! ```
@@ -109,7 +122,7 @@
 //! Way 1: ensure the bounds with [`Ranged::new(i128) -> Option<Ranged>`](struct.Ranged.html#method.new) function
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! let some_int = 4;
 //! let some_wrong_int = 8;
 //! assert!(Ranged::<0, 6>::new(some_int) == Some(r!([0 6] 4)));
@@ -121,17 +134,17 @@
 //! Way 2: use the [`Remainder operation`](struct.Ranged.html#impl-Rem<Ranged<VAL%2C%20VAL>>) with the "const" divisor
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! let x: Ranged<-9, 9> = 15_i32 % r!(10);
 //! let y: Ranged<0, 9> = 15_u32 % r!(10);
 //! assert!(x == r!(5));
 //! assert!(y == r!(5));
 //! ```
 //!
-//! Way 3: Convert the primitive types to `Ranged` with their native bounds using [`AsRanged`](trait.AsRanged.html)
+//! Way 3: Convert the primitive types to `Ranged` with their native bounds using [`AsRanged`]
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! use ranged_integers::AsRanged;
 //! let x = 15_u8.as_ranged();  // Ranged<0, 255>
 //! let y = 15_i16.as_ranged(); // Ranged<-32768, 32767>
@@ -143,52 +156,70 @@
 //! fit into the result type:
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*;
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*;
 //! let x = r!([0 200] 20);
 //! let y: u8 = x.into();  // 0..=200 fits u8
 //! ```
 //!
 //! ```compile_fail
-//! # #![feature(const_generics)] use ranged_integers::*;
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*;
 //! let x = r!([0 200] 20);
 //! let y: i8 = x.into();  // 0..=200 doesn't fit i8
 //! ```
 //!
 //! `From` and `Into` operations can't be used in const context.
-//! The set of [`const fn`s](struct.Ranged.html#method.i8) allows const conversions to 
+//! A set of [`const fn`](struct.Ranged.html#method.i8)s allows const conversions to 
 //! any integer primitive except for `u128`:
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! let x = r!([0 200] 20);
 //! let y = x.u8(); // y is u8
 //! let z = x.i16(); // z is i16
-//! let w = x.usize(); // z is i16
+//! let w = x.usize(); // w is usize
 //! ```
 //!
 //! ```compile_fail
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! let x = r!([0 200] 20);
 //! let err = x.i8();  // Error: 0..=200 doesn't fit i8
 //! ```
 //!
+//! ## Array indexing and iteration
+//!
+//! The [`range<RANGE>`] function creates an iterator through the `RANGE = MIN..END = MIN..=MAX` range
+//! with `Ranged<MIN, MAX>` output type.
+//! The arrays `[T; N]` may be indexed with `Ranged<0, {N-1}>`:
+//! ```
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! let arr = [r!([1 6] 2), r!([] 3), r!([] 4)];
+//! for i in range::<{0..3}>() {
+//!     move_player(arr[i])
+//! }
+//! ```
+//!
 //! ## Comparison
 //!
 //! Equality and inequality operations between different Ranged types are allowed:
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! assert!(r!([1 6] 4) == r!([1 10] 4));
 //! assert!(r!([1 6] 4) != r!([1 6] 5));
 //! ```
 //!
 //! ## Arithmetics
 //!
-//! The basic arithmetic operations, min() and max() functions are implemented.
-//! The bounds of values are automatically recalculated:
+//! The bounds of arithmetic operations results are automatically recalculated.
+//!
+//! Currently supported:
+//! * The basic arithmetic operations (+, -, *, /)
+//! * [`div_euclid()`](struct.Ranged.html#method.div_euclid) and [`rem_euclid()`](struct.Ranged.html#method.rem_euclid)
+//! * [`min()`](struct.Ranged.html#method.min) and [`max()`](struct.Ranged.html#method.max)
+//! * [`abs()`](struct.Ranged.html#method.abs)
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! let x = r!([1 6] 5);
 //! let y = r!([1 6] 4);
 //!
@@ -218,12 +249,13 @@
 //! 
 //! let min: Ranged<1,6> = x.min(a);
 //! let max: Ranged<2,12> = x.max(a);
+//! let abs: Ranged<0,6> = r!([-1 6] -1).abs();
 //! ```
 //!
 //! The division and remainder are allowed only if it's impossible to store "0" in the divisor:
 //!
 //! ```compile_fail
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! let x = r!([1 6] 4);
 //! let y = r!([0 6] 5);
 //! let z = r!([-1 6] 5);
@@ -238,7 +270,7 @@
 //!
 //! This kind of `Rem` followed by `expand` is available for any dividend:
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*;
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*;
 //! let x = r!([-1000 1000] 500);
 //! let y = r!([-1 1000] 500);
 //! let d = r!([1 10] 7);
@@ -253,7 +285,7 @@
 //! But the actual calculation routine can produce smaller bounds:
 //!
 //! ```
-//! # #![feature(const_generics)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
+//! # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; fn move_player(dice_roll: Ranged<1, 6>) {}
 //! // In the general case the output is Ranged<1-MAX, MAX-1>, MAX from divisor (by absolute value)
 //! let x: Ranged<-9, 9> = (r!([-1000 1000] 500) % r!([1 10] 7));
 //! let x: Ranged<-9, 9> = (r!([-1000 1000] 500) % r!([-10 -1] -7));
@@ -280,12 +312,15 @@
 
 #![no_std]
 #![allow(incomplete_features)]
-#![feature(const_generics)]
-#![feature(const_evaluatable_checked)]
+
+#![feature(adt_const_params)]
+#![feature(generic_const_exprs)]
+
 #![feature(const_panic)]
 #![feature(const_trait_impl)]
 #![feature(const_raw_ptr_deref)]
 #![feature(specialization)]
+#![feature(inline_const)]
 
 #![deny(missing_docs)]
 #![deny(clippy::nursery)]
@@ -302,13 +337,7 @@ mod tests;
 pub mod value_check;
 use value_check::{Assert, IsAllowed, OperationPossibility};
 
-pub mod holder;
-use holder::{IntLayout, NumberBytes};
-
-mod conversions;
-mod arithmetics;
-
-pub use conversions::AsRanged;
+mod holder;
 
 #[allow(non_camel_case_types)]
 type irang = i128;
@@ -318,32 +347,28 @@ type irang = i128;
 /// Panics to emit an error when min>max.
 #[must_use]
 #[doc(hidden)]
-pub const fn memlayout(min: irang, max: irang) -> IntLayout {
-    macro_rules! crange {
+pub const fn memlayout(min: irang, max: irang) -> holder::IntLayout {
+    macro_rules! layout_variants {
         ($($t:ident)+) => {
-            $(
-                if core::$t::MIN as irang <= min && max <= core::$t::MAX as irang {return IntLayout::$t}
-            )+
+            $(   if core::$t::MIN as irang <= min && max <= core::$t::MAX as irang {return holder::IntLayout::$t}   )+
         }
     }
-
     if min == max {
-        return IntLayout::Trivial;
+        return holder::IntLayout::Trivial;
     }
     if min > max {
         panic!("Ranged error: MIN cannot be greater than MAX");
     }
-    crange! {i8 u8 i16 u16 i32 u32 i64 u64}
-    IntLayout::i128
+    layout_variants! {i8 u8 i16 u16 i32 u32 i64 u64}
+    holder::IntLayout::i128
 }
 
 /// A value restricted to the given bounds
 #[derive(Clone, Copy)]
 pub struct Ranged<const MIN: irang, const MAX: irang>
-where
-    [u8; memlayout(MIN, MAX).bytes()]: ,
+where [u8; memlayout(MIN, MAX).bytes()]:,
 {
-    v: NumberBytes<{ memlayout(MIN, MAX) }>,
+    v: holder::NumberBytes<{ memlayout(MIN, MAX) }>,
 }
 
 #[must_use]
@@ -356,13 +381,37 @@ impl<const MIN: irang, const MAX: irang> Ranged<MIN, MAX>
 where
     [u8; memlayout(MIN, MAX).bytes()]: ,
 {
+    #[allow(clippy::inline_always)] #[must_use] #[inline(always)]
     const unsafe fn __unsafe_new(n: irang) -> Self {
         Self {
-            v: NumberBytes::from_irang(n),
+            v: holder::NumberBytes::from_irang(n),
         }
     }
 
-    /// Create a Ranged value with a runtime bounds checking
+    #[allow(clippy::inline_always)] #[must_use] #[inline(always)]
+    /// Convert Ranged to a primitive
+    const fn get(self) -> irang {
+        if MIN == MAX {MIN}
+        else {self.v.to_irang()}
+    }
+
+    /// Create a Ranged value checking the bounds at runtime
+    /// 
+    /// # Example
+    /// 
+    /// ```
+    /// # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; 
+    /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let input = "42".to_string();
+    /// let user_input = input.parse()?;
+    /// if let Some(input) = Ranged::<1, 100>::new(user_input){
+    ///     println!("The value is in range 1..=100")
+    /// }
+    /// else {
+    ///     println!("The value is too high :(")
+    /// }
+    /// # Ok(()) }
+    /// ```
     #[must_use]
     pub const fn new(n: irang) -> Option<Self> {
         if (MIN <= n) && (n <= MAX) {
@@ -372,30 +421,46 @@ where
         }
     }
 
-    /// Create a Ranged value with a compile time bounds checking
+    /// Create a Ranged constant checking the bounds at compile time
+    /// 
+    /// Consider using [`r!`] macro instead
+    /// 
+    /// # Example
+    /// 
+    /// ```
+    /// # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*; 
+    /// let a = Ranged::<0, 100>::create_const::<42>();
+    /// let a = r!([0 100] 42);
+    /// ```
     #[must_use]
     pub const fn create_const<const V: irang>() -> Self
-    where
-        Assert<{ OperationPossibility::allow_if(allow_creation(MIN, V, MAX)) }>: IsAllowed,
+    where Assert<{ OperationPossibility::allow_if(allow_creation(MIN, V, MAX)) }>: IsAllowed,
     {
         unsafe { Self::__unsafe_new(V) }
     }
 
-    /// Convert Ranged to a primitive
-    const fn get(self) -> irang {
-        if MIN == MAX {MIN}
-        else {self.v.to_irang()}
+    /// Iterate up from current value to `Self::MAX` (inclusively) using `Self` as output
+    #[must_use]
+    pub const fn iter_up(self) -> iter::Iter<MIN, MAX> {
+        iter::Iter::<MIN,MAX>{current: Some(self)}
     }
 }
 
+mod conversions;
+pub use conversions::AsRanged;
+mod arithmetics;
+mod iter;
+pub use iter::range as range;
+
+
 /// Create a ranged value at compile time
 ///
-/// **Warning**: ensure `#![feature(const_generics)]` is enabled.
+/// **Warning**: ensure `#![feature(adt_const_params)]` is enabled.
 ///
 /// # Example
 ///
 /// ```
-/// # #![feature(const_generics)] use ranged_integers::*;
+/// # #![feature(adt_const_params, generic_const_exprs)] use ranged_integers::*;
 /// // Explicit bounds:
 /// let a = r!([0 42] 23);  // Ranged<0, 42> with a value 23
 /// // Type inference:
@@ -445,90 +510,112 @@ pub const fn max_irang(x: irang, y: irang) -> irang {
     if x > y {x} else {y}
 }
 
+#[allow(clippy::cast_sign_loss)]
+impl<T, const N: usize> core::ops::Index<Ranged<0, {N as i128 - 1}>> for [T; N]
+where 
+    [u8; memlayout(0, N as i128 - 1).bytes()]:,
+    Assert<{conversions::converter_checkers::usize(0, N as i128 - 1)}>: IsAllowed
+{
+    type Output = T;
+    fn index(&self, index: Ranged<0, {N as i128 - 1}>) -> &Self::Output {
+        unsafe{self.get_unchecked(index.usize())}
+    }
+}
+
+#[allow(clippy::cast_sign_loss)]
+impl<T, const N: usize> core::ops::IndexMut<Ranged<0, {N as i128 - 1}>> for [T; N]
+where 
+    [u8; memlayout(0, N as i128 - 1).bytes()]:,
+    Assert<{conversions::converter_checkers::usize(0, N as i128 - 1)}>: IsAllowed
+{
+    fn index_mut(&mut self, index: Ranged<0, {N as i128 - 1}>) -> &mut Self::Output {
+        unsafe{self.get_unchecked_mut(index.usize())}
+    }
+}
 
 
 #[allow(dead_code)]
 #[doc(hidden)]
 /**
 ```
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 u8::from(r!(0));
 ```
 
 ```compile_fail
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 u8::from(r!(-1));
 ```
 
 ```
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 u8::from(r!(255));
 ```
 
 ```compile_fail
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 u8::from(r!(256));
 ```
 
 ```
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 i8::from(r!(-128));
 ```
 
 
 ```compile_fail
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 i8::from(r!(-129));
 ```
 
 ```
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 i8::from(r!(127));
 ```
 
 
 ```compile_fail
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 i8::from(r!(128));
 ```
 
 
 ```
-# #![feature(const_panic)] #![feature(const_generics)] #![feature(const_evaluatable_checked)]
+# #![feature(const_panic)] #![feature(adt_const_params)] #![feature(generic_const_exprs)]
 # #[macro_use] extern crate ranged_integers; use ranged_integers::*;
 let a = r![[100 1000] 500] / r![[1 6] 5];
 ```
 ```compile_fail
-# #![feature(const_panic)] #![feature(const_generics)] #![feature(const_evaluatable_checked)]
+# #![feature(const_panic)] #![feature(adt_const_params)] #![feature(generic_const_exprs)]
 # #[macro_use] extern crate ranged_integers; use ranged_integers::*;
 let a = r![[100 1000] 500] / r![[0 6] 5];
 ```
 ```compile_fail
-# #![feature(const_panic)] #![feature(const_generics)] #![feature(const_evaluatable_checked)]
+# #![feature(const_panic)] #![feature(adt_const_params)] #![feature(generic_const_exprs)]
 # #[macro_use] extern crate ranged_integers; use ranged_integers::*;
 let a = r![[100 1000] 500] / r![[-1 6] 5];
 ```
 
 ```
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 Ranged::<0,1>::new(1);
 ```
 
 
 ```compile_fail
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 Ranged::<1,0>::new(1);
 ```
 
 
 ```
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 let x: Ranged::<0,1> = Ranged::<0,1>::new(1).unwrap();
 ```
 
 
 ```
-# #![feature(const_generics)] #![feature(const_panic)] use ranged_integers::*;
+# #![feature(adt_const_params)] #![feature(const_panic)] use ranged_integers::*;
 let x: Ranged::<0,1> = Ranged::new(1).unwrap();
 ```
 */
